@@ -125,7 +125,11 @@ class sentence_tranformer_checker():
         self.remove_stop_words = remove_stop_words
         self.stemm = stemm
         self.lang = lang 
-        self.device = device.lower()
+        
+        if device is None:
+            self.device = None
+        else:
+            self.device = device.lower()
 
         if isinstance(targets, pd.DataFrame):
             self.use_frames = True
